@@ -34,7 +34,6 @@ GQuark log_matcher_error_quark(void);
 
 enum
 {
-  /* use global search/replace */
   /* use global search/replace */
   LMF_GLOBAL = 0x0001,
   LMF_ICASE  = 0x0002,
@@ -44,12 +43,14 @@ enum
   LMF_NEWLINE= 0x0008,
   LMF_UTF8   = 0x0010,
   LMF_STORE_MATCHES = 0x0020,
-  LMF_VALID_REGEXP_FLAGS = 0x0037,
+  LMF_DISABLE_JIT = 0x0040,
 
   /* string flags */
-  LMF_SUBSTRING = 0x0040,
-  LMF_PREFIX = 0x0080,
-  LMF_VALID_STRING_FLAGS = 0x00C7,
+  LMF_SUBSTRING = 0x0080,
+  LMF_PREFIX = 0x0100,
+
+  /*  advanced LIBPCRE flags */
+  LMF_DUPNAMES = 0x00080000,
 };
 
 typedef struct _LogMatcherOptions
@@ -64,15 +65,17 @@ struct _LogMatcher
 {
   gint ref_cnt;
   gint flags;
+  gchar *pattern;
   gboolean (*compile)(LogMatcher *s, const gchar *re, GError **error);
   /* value_len can be -1 to indicate unknown length */
   gboolean (*match)(LogMatcher *s, LogMessage *msg, gint value_handle, const gchar *value, gssize value_len);
   /* value_len can be -1 to indicate unknown length, new_length can be returned as -1 to indicate unknown length */
-  gchar *(*replace)(LogMatcher *s, LogMessage *msg, gint value_handle, const gchar *value, gssize value_len, LogTemplate *replacement, gssize *new_length);
+  gchar *(*replace)(LogMatcher *s, LogMessage *msg, gint value_handle, const gchar *value, gssize value_len,
+                    LogTemplate *replacement, gssize *new_length);
   void (*free_fn)(LogMatcher *s);
 };
 
-static inline gboolean 
+static inline gboolean
 log_matcher_compile(LogMatcher *s, const gchar *re, GError **error)
 {
   return s->compile(s, re, error);
@@ -85,7 +88,8 @@ log_matcher_match(LogMatcher *s, LogMessage *msg, gint value_handle, const gchar
 }
 
 static inline gchar *
-log_matcher_replace(LogMatcher *s, LogMessage *msg, gint value_handle, const gchar *value, gssize value_len, LogTemplate *replacement, gssize *new_length)
+log_matcher_replace(LogMatcher *s, LogMessage *msg, gint value_handle, const gchar *value, gssize value_len,
+                    LogTemplate *replacement, gssize *new_length)
 {
   if (s->replace)
     return s->replace(s, msg, value_handle, value, value_len, replacement, new_length);
@@ -104,12 +108,11 @@ log_matcher_is_replace_supported(LogMatcher *s)
   return s->replace != NULL;
 }
 
-LogMatcher *log_matcher_posix_re_new(GlobalConfig *cfg, const LogMatcherOptions *options);
-LogMatcher *log_matcher_pcre_re_new(GlobalConfig *cfg, const LogMatcherOptions *options);
-LogMatcher *log_matcher_string_new(GlobalConfig *cfg, const LogMatcherOptions *options);
-LogMatcher *log_matcher_glob_new(GlobalConfig *cfg, const LogMatcherOptions *options);
+LogMatcher *log_matcher_pcre_re_new(const LogMatcherOptions *options);
+LogMatcher *log_matcher_string_new(const LogMatcherOptions *options);
+LogMatcher *log_matcher_glob_new(const LogMatcherOptions *options);
 
-LogMatcher *log_matcher_new(GlobalConfig *cfg, const LogMatcherOptions *options);
+LogMatcher *log_matcher_new(const LogMatcherOptions *options);
 LogMatcher *log_matcher_ref(LogMatcher *s);
 void log_matcher_unref(LogMatcher *s);
 
@@ -117,7 +120,9 @@ void log_matcher_unref(LogMatcher *s);
 gboolean log_matcher_options_set_type(LogMatcherOptions *options, const gchar *type);
 gboolean log_matcher_options_process_flag(LogMatcherOptions *self, const gchar *flag);
 void log_matcher_options_defaults(LogMatcherOptions *options);
-void log_matcher_options_init(LogMatcherOptions *options, GlobalConfig *cfg);
+void log_matcher_options_init(LogMatcherOptions *options);
 void log_matcher_options_destroy(LogMatcherOptions *options);
 
+void log_matcher_pcre_set_nv_prefix(LogMatcher *s, const gchar *prefix);
+
 #endif
