@@ -25,53 +25,105 @@
 #define STATS_COUNTER_H_INCLUDED 1
 
 #include "syslog-ng.h"
+#include "atomic-gssize.h"
 
 typedef struct _StatsCounterItem
 {
-  gint value;
+  union
+  {
+    atomic_gssize value;
+    atomic_gssize *value_ref;
+  };
+  gchar *name;
+  gint type;
+  gboolean external;
 } StatsCounterItem;
 
 
+static gboolean
+stats_counter_read_only(StatsCounterItem *counter)
+{
+  return counter->external;
+}
+
 static inline void
-stats_counter_add(StatsCounterItem *counter, gint add)
+stats_counter_add(StatsCounterItem *counter, gssize add)
 {
   if (counter)
-    g_atomic_int_add(&counter->value, add);
+    {
+      g_assert(!stats_counter_read_only(counter));
+      atomic_gssize_add(&counter->value, add);
+    }
+}
+
+static inline void
+stats_counter_sub(StatsCounterItem *counter, gssize sub)
+{
+  if (counter)
+    {
+      g_assert(!stats_counter_read_only(counter));
+      atomic_gssize_sub(&counter->value, sub);
+    }
 }
 
 static inline void
 stats_counter_inc(StatsCounterItem *counter)
 {
   if (counter)
-    g_atomic_int_inc(&counter->value);
+    {
+      g_assert(!stats_counter_read_only(counter));
+      atomic_gssize_inc(&counter->value);
+    }
 }
 
 static inline void
 stats_counter_dec(StatsCounterItem *counter)
 {
   if (counter)
-    g_atomic_int_add(&counter->value, -1);
+    {
+      g_assert(!stats_counter_read_only(counter));
+      atomic_gssize_dec(&counter->value);
+    }
 }
 
 /* NOTE: this is _not_ atomic and doesn't have to be as sets would race anyway */
 static inline void
-stats_counter_set(StatsCounterItem *counter, guint32 value)
+stats_counter_set(StatsCounterItem *counter, gsize value)
 {
-  if (counter)
-    counter->value = value;
+  if (counter && !stats_counter_read_only(counter))
+    {
+      atomic_gssize_racy_set(&counter->value, value);
+    }
 }
 
 /* NOTE: this is _not_ atomic and doesn't have to be as sets would race anyway */
-static inline guint32
+static inline gsize
 stats_counter_get(StatsCounterItem *counter)
 {
-  guint32 result = 0;
+  gsize result = 0;
 
   if (counter)
-    result = counter->value;
+    {
+      if (!counter->external)
+        result = atomic_gssize_get_unsigned(&counter->value);
+      else
+        result = atomic_gssize_get_unsigned(counter->value_ref);
+    }
   return result;
 }
 
-void stats_reset_non_stored_counters(void);
+static inline gchar *
+stats_counter_get_name(StatsCounterItem *counter)
+{
+  if (counter)
+    return counter->name;
+  return NULL;
+}
+
+static inline void
+stats_counter_free(StatsCounterItem *counter)
+{
+  g_free(counter->name);
+}
 
 #endif
