@@ -22,8 +22,8 @@
  *
  */
 
-#ifndef TEMPLATE_FUNCTION_H_INCLUDED
-#define TEMPLATE_FUNCTION_H_INCLUDED
+#ifndef TEMPLATE_USER_FUNCTION_H_INCLUDED
+#define TEMPLATE_USER_FUNCTION_H_INCLUDED
 
 #include "syslog-ng.h"
 
